summaryrefslogtreecommitdiff
path: root/openttd.h
diff options
context:
space:
mode:
authortruelight <truelight@openttd.org>2006-08-19 10:00:30 +0000
committertruelight <truelight@openttd.org>2006-08-19 10:00:30 +0000
commit10b842bddcbe6cdcf7111736bec985cdc13e528f (patch)
treecd9ad6758b68622254b2545359b5d87f88f7074b /openttd.h
parent83d56d6d798a28169f00a4c67323a407037c0b0a (diff)
downloadopenttd-10b842bddcbe6cdcf7111736bec985cdc13e528f.tar.xz
(svn r5946) -Add: merged the TGP branch to mainline. TGP adds:
- New optional landscape generator (TerraGenesis Perlin) - Load heightmaps (either BMP or PNG) - Progress dialog while generating worlds (no longer a 'hanging' screen) - New dialogs for NewGame, Create Scenario and Play Heightmap - Easier to configure your landscape - More things to configure (tree-placer, ..) - Speedup of world generation - New console command 'restart': restart the map EXACTLY as it was when you first started it (needs a game made after or with this commit) - New console command 'getseed': get the seed of your map and share it with others (of course only works with generated maps) - Many new, world generation related, things - Many internal cleanups and rewrites Many tnx to those people who helped making this: Belugas, DaleStan, glx, KUDr, RichK67, Rubidium, and TrueLight (alfabetic) Many tnx to those who helped testing: Arnau, Bjarni, and tokai (alfabetic) And to all other people who helped testing and sending comments / bugs Stats: 673 lines changed, 3534 new lines, 79 new strings
Diffstat (limited to 'openttd.h')
-rw-r--r--openttd.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/openttd.h b/openttd.h
index 21650b922..bf309e27b 100644
--- a/openttd.h
+++ b/openttd.h
@@ -77,14 +77,17 @@ enum SwitchModes {
SM_GENRANDLAND = 6,
SM_LOAD_SCENARIO = 9,
SM_START_SCENARIO = 10,
+ SM_START_HEIGHTMAP = 11,
+ SM_LOAD_HEIGHTMAP = 12,
};
/* Modes for GenerateWorld */
enum GenerateWorldModes {
- GW_NEWGAME = 0, /* Generate a map for a new game */
- GW_EMPTY = 1, /* Generate an empty map (sea-level) */
- GW_RANDOM = 2, /* Generate a random map for SE */
+ GW_NEWGAME = 0, /* Generate a map for a new game */
+ GW_EMPTY = 1, /* Generate an empty map (sea-level) */
+ GW_RANDOM = 2, /* Generate a random map for SE */
+ GW_HEIGHTMAP = 3, /* Generate a newgame from a heightmap */
};
/* Modes for InitializeGame, those are _bits_! */
@@ -410,6 +413,9 @@ enum {
WC_HIGHSCORE = 0x4D,
WC_ENDSCREEN = 0x4E,
WC_SIGN_LIST = 0x4F,
+ WC_GENERATE_LANDSCAPE = 0x50,
+ WC_GENERATE_PROGRESS_WINDOW = 0x51,
+ WC_OK_CANCEL_QUERY = 0x52,
};